@@ -35,6 +35,12 @@
 #include "capplet-util.h"
 #include "gconf-property-editor.h"
 
+enum
+{
+	RESPONSE_APPLY = 1,
+	RESPONSE_CLOSE
+};
+
 static GladeXML *
 create_dialog (void)
 {
@@ -78,6 +84,7 @@ rate_from_widget (GConfValue *value)
 
 	new_value = gconf_value_new (GCONF_VALUE_INT);
 	gconf_value_set_int (new_value, rates[gconf_value_get_int (value)]);
+
 	return new_value;
 }
 
@@ -150,6 +157,31 @@ bell_to_widget (GConfValue *value)
 	return new_value;
 }
 
+
+static GConfValue *
+blink_from_widget (GConfValue *value) 
+{
+	GConfValue *new_value;
+
+	new_value = gconf_value_new (GCONF_VALUE_INT);
+	gconf_value_set_int (new_value, 2600 - (int) gconf_value_get_float (value));
+
+	return new_value;
+}
+
+static GConfValue *
+blink_to_widget (GConfValue *value) 
+{
+	GConfValue *new_value;
+	gint current_rate;
+
+	current_rate = gconf_value_get_int (value);
+	new_value = gconf_value_new (GCONF_VALUE_FLOAT);
+	gconf_value_set_float (new_value, CLAMP (2600 - current_rate, 100, 2500));
+
+	return new_value;
+}
+
 static void
 bell_guard (GtkWidget *toggle,
 	    GladeXML  *dialog)
@@ -167,6 +199,22 @@ mnemonic_activate (GtkWidget *toggle,
 	return FALSE;
 }
 
+
+static void
+dialog_response (GtkWidget *widget,
+		 gint       response_id,
+		 GConfChangeSet *changeset)
+{
+	switch (response_id)
+	{
+	case RESPONSE_CLOSE:
+	case GTK_RESPONSE_DELETE_EVENT:
+	default:
+		gtk_main_quit ();
+		break;
+	}
+}
+
 static void
 setup_dialog (GladeXML       *dialog,
 	      GConfChangeSet *changeset)
@@ -195,13 +243,13 @@ setup_dialog (GladeXML       *dialog,
 	gconf_peditor_widget_set_guard (GCONF_PROPERTY_EDITOR (peditor), WID ("repeat_table"));
 
 	gconf_peditor_new_select_menu
-		(changeset, "/gnome/desktop/peripherals/keyboard/delay", WID ("repeat_delay_omenu"),
+		(changeset, "/desktop/gnome/peripherals/keyboard/delay", WID ("repeat_delay_omenu"),
 		 "conv-to-widget-cb", delay_to_widget,
 		 "conv-from-widget-cb", delay_from_widget,
 		 NULL);
 
 	gconf_peditor_new_select_menu
-		(changeset, "/gnome/desktop/peripherals/keyboard/rate", WID ("repeat_speed_omenu"),
+		(changeset, "/desktop/gnome/peripherals/keyboard/rate", WID ("repeat_speed_omenu"),
 		 "conv-to-widget-cb", rate_to_widget,
 		 "conv-from-widget-cb", rate_from_widget,
 		 NULL);
@@ -210,14 +258,17 @@ setup_dialog (GladeXML       *dialog,
 		(changeset, "/desktop/gnome/interface/cursor_blink", WID ("cursor_toggle"), NULL);
 	gconf_peditor_widget_set_guard (GCONF_PROPERTY_EDITOR (peditor), WID ("cursor_hbox"));
 	gconf_peditor_new_numeric_range
-		(changeset, "/desktop/gnome/interface/cursor_blink_time", WID ("cursor_blink_time_scale"), NULL);
+		(changeset, "/desktop/gnome/interface/cursor_blink_time", WID ("cursor_blink_time_scale"),
+		 "conv-to-widget-cb", blink_to_widget,
+		 "conv-from-widget-cb", blink_from_widget,
+		 NULL);
 
 
 	peditor = gconf_peditor_new_boolean
 		(changeset, "/desktop/gnome/peripherals/keyboard/click", WID ("volume_toggle"), NULL);
 	gconf_peditor_widget_set_guard (GCONF_PROPERTY_EDITOR (peditor), WID ("volume_hbox"));
 	gconf_peditor_new_numeric_range
-		(changeset, "/desktop/gnome/peripherals/keyboard/clickvolume", WID ("volume_scale"), NULL);
+		(changeset, "/desktop/gnome/peripherals/keyboard/click_volume", WID ("volume_scale"), NULL);
 	
 	g_signal_connect (G_OBJECT (WID ("bell_custom_radio")), "toggled", (GCallback) bell_guard, dialog);
 	peditor = gconf_peditor_new_select_radio
@@ -227,7 +278,7 @@ setup_dialog (GladeXML       *dialog,
 		 "conv-from-widget-cb", bell_from_widget,
 		 NULL);
 	g_signal_connect (G_OBJECT (WID ("bell_custom_radio")), "mnemonic_activate", (GCallback) mnemonic_activate, WID ("bell_custom_entry"));
-		 
+	g_signal_connect (G_OBJECT (WID ("keyboard_dialog")), "response", (GCallback) dialog_response, changeset);
 }
 
 static void
@@ -254,6 +305,7 @@ int
 main (int argc, char **argv) 
 {
 	GConfClient    *client;
+	GConfChangeSet *changeset;
 	GladeXML       *dialog;
 
 	static gboolean apply_only;
@@ -284,8 +336,9 @@ main (int argc, char **argv)
 	if (get_legacy) {
 		get_legacy_settings ();
 	} else {
+		changeset = NULL;
 		dialog = create_dialog ();
-		setup_dialog (dialog, NULL);
+		setup_dialog (dialog, changeset);
 
 		gtk_widget_show_all (WID ("keyboard_dialog"));
 		gtk_main ();
