@@ -57,7 +57,7 @@ create_dialog (void)
 
 	data = glade_xml_new (GNOMECC_DATA_DIR "/interfaces/sound-properties.glade", "prefs_widget", NULL);
 	widget = glade_xml_get_widget (data, "prefs_widget");
-	gtk_object_set_data (GTK_OBJECT (widget), "glade-data", data);
+	g_object_set_data (G_OBJECT (widget), "glade-data", data);
 
 	props = sound_properties_new ();
 	sound_properties_add_defaults (props, NULL);
@@ -65,11 +65,10 @@ create_dialog (void)
 	gtk_box_pack_start (GTK_BOX (box), sound_view_new (props),
 			    TRUE, TRUE, 0);
 
-	gtk_signal_connect_object (GTK_OBJECT (widget), "destroy",
-				   GTK_SIGNAL_FUNC (gtk_object_destroy),
-				   GTK_OBJECT (props));
+	g_signal_connect_swapped (G_OBJECT (widget), "destroy",
+				  (GCallback) gtk_object_destroy, props);
 
-	gtk_widget_set_usize (widget, -1, 250);
+	gtk_widget_set_size_request (widget, -1, 250);
 
 	return data;
 }
@@ -84,10 +83,10 @@ setup_dialog (GladeXML *dialog, GConfChangeSet *changeset)
 {
 	GObject *peditor;
 
-	peditor = gconf_peditor_new_boolean (changeset, "/desktop/gnome/sound/enable_esd", WID ("enable_toggle"), NULL);
+	peditor = gconf_peditor_new_boolean (NULL, "/desktop/gnome/sound/enable_esd", WID ("enable_toggle"), NULL);
 	gconf_peditor_widget_set_guard (GCONF_PROPERTY_EDITOR (peditor), WID ("events_toggle"));
 	gconf_peditor_widget_set_guard (GCONF_PROPERTY_EDITOR (peditor), WID ("events_vbox"));
-	peditor = gconf_peditor_new_boolean (changeset, "/desktop/gnome/sound/event_sounds", WID ("events_toggle"), NULL);
+	peditor = gconf_peditor_new_boolean (NULL, "/desktop/gnome/sound/event_sounds", WID ("events_toggle"), NULL);
 }
 
 /* get_legacy_settings
@@ -112,13 +111,9 @@ get_legacy_settings (void)
 }
 
 static void
-dialog_button_clicked_cb (GnomeDialog *dialog, gint response_id, GConfChangeSet *changeset) 
+dialog_button_clicked_cb (GtkDialog *dialog, gint response_id, GConfChangeSet *changeset) 
 {
 	switch (response_id) {
-	case GTK_RESPONSE_APPLY:
-		gconf_client_commit_change_set (gconf_client_get_default (), changeset, TRUE, NULL);
-		break;
-
 	case GTK_RESPONSE_CLOSE:
 		gtk_main_quit ();
 		break;
@@ -170,7 +165,6 @@ main (int argc, char **argv)
 
 		dialog_win = gtk_dialog_new_with_buttons
 			(_("Sound properties"), NULL, -1,
-			 GTK_STOCK_APPLY, GTK_RESPONSE_APPLY,
 			 GTK_STOCK_CLOSE, GTK_RESPONSE_CLOSE,
 			 NULL);
 
