@@ -246,7 +246,7 @@ strip_ext (const gchar *filename, const gchar *suffix)
 	}
 				
 	elen = strlen (suffix);
-	if (g_strcasecmp (filename + flen - elen, suffix) == 0)
+	if (g_ascii_strcasecmp (filename + flen - elen, suffix) == 0)
 	{
 		ret = g_new0 (gchar, flen - elen + 1);
 		strncpy (ret, filename, flen - elen);
@@ -344,14 +344,16 @@ void
 sound_properties_add_file (SoundProperties *props, gchar *filename,
 			   gboolean is_user, gchar *themedir)
 {
-	gchar *prefix;
+	gchar *prefix, *basename;
 	gchar *category, *cat_desc, *name;
 	gpointer i;
 
 	g_return_if_fail (SOUND_IS_PROPERTIES (props));
 	g_return_if_fail (filename != NULL);
 
-	category = strip_ext (g_basename (filename), ".soundlist");
+	basename = g_path_get_basename (filename);
+	category = strip_ext (basename, ".soundlist");
+	g_free (basename);
 	
 	if (!category)
 		return;
